"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseStringARParam = void 0;
var joi_1 = __importDefault(require("joi"));
var number_1 = require("./number");
var StringAspectRatioSchema = joi_1.default.string()
    .pattern(/^\d+(\.\d+)?:\d+(\.\d+)?$/)
    .required();
/**
 * Parse a string AR into a float.
 */
var parseStringARParam = function (ar) {
    var validatedAR = StringAspectRatioSchema.validate(ar);
    if (validatedAR.error) {
        throw new Error('AR is not valid. ' + validatedAR.error.message);
    }
    var splitAR = validatedAR.value.split(':');
    var _a = splitAR.map(function (part) { return parseFloat(part); }), parsedWidth = _a[0], parsedHeight = _a[1];
    if (Number.isNaN(parsedWidth) || Number.isNaN(parsedHeight)) {
        throw new Error('AR is not valid, since the parsed width or height are not numbers.');
    }
    var arFloat = parsedWidth / parsedHeight;
    return (0, number_1.roundToDP)(3, arFloat);
};
exports.parseStringARParam = parseStringARParam;
//# sourceMappingURL=ar.js.map