"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withCache = void 0;
var log_1 = require("./log");
var log = (0, log_1.createLogger)('cache');
/**
 * Use the Gatsby cache to cache information. Use the cache key to search for a
 * value, and if it doesn't exist, call f to get the value and cache it.
 * Finally, return the value.
 *
 * In this project we cache various things, such as metadata from images. This
 * reduces the amount of requests that this project has to make to the imgix
 * API, speeding up the build, and also reduces the loads on imgix's servers.
 * Furthermore, this cache is persisted across builds (not just during one
 * build), so this will speed up all subsequent builds.
 *
 * @param key The cache key to use
 * @param cache The Gatsby cache
 * @param f The function to call if there is a cache miss. Returns a Promise.
 * @returns The value in the cache or the resolved value of f.
 */
var withCache = function (key, cache, f) { return __awaiter(void 0, void 0, void 0, function () {
    var data, error_1, newData, error_2;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                _a.trys.push([0, 2, , 8]);
                log("Trying to retrieve ".concat(key, " from cache"));
                return [4 /*yield*/, getFromCache(cache, key)];
            case 1:
                data = _a.sent();
                (0, log_1.traceJSON)(data, "Successfully retrieved ".concat(key, " from cache with value"), log);
                return [2 /*return*/, data];
            case 2:
                error_1 = _a.sent();
                return [4 /*yield*/, f()];
            case 3:
                newData = _a.sent();
                (0, log_1.traceJSON)(newData, "Couldn't retrieve ".concat(key, " from cache, replacing with value"));
                _a.label = 4;
            case 4:
                _a.trys.push([4, 6, , 7]);
                return [4 /*yield*/, setToCache(cache, key, newData)];
            case 5:
                _a.sent();
                return [3 /*break*/, 7];
            case 6:
                error_2 = _a.sent();
                throw new Error('Error with cache');
            case 7: return [2 /*return*/, newData];
            case 8: return [2 /*return*/];
        }
    });
}); };
exports.withCache = withCache;
var getFromCache = function (cache, key) { return __awaiter(void 0, void 0, void 0, function () {
    var cacheData, error_3;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                _a.trys.push([0, 2, , 3]);
                return [4 /*yield*/, cache.get(key)];
            case 1:
                cacheData = (_a.sent());
                return [3 /*break*/, 3];
            case 2:
                error_3 = _a.sent();
                throw new Error("Failed to get \"".concat(key, "\" in cache."));
            case 3:
                (0, log_1.traceJSON)(cacheData, "Retrieved value from cache for ".concat(key), log);
                if (cacheData == null) {
                    log("Key ".concat(key, " doesn't exist in the cache"));
                    throw new Error("Key ".concat(key, " doesn't exist in the cache"));
                }
                return [2 /*return*/, cacheData];
        }
    });
}); };
var setToCache = function (cache, key, value) { return __awaiter(void 0, void 0, void 0, function () {
    return __generator(this, function (_a) {
        (0, log_1.traceJSON)(value, "Setting \"".concat(key, "\" in cache to"), log);
        try {
            cache.set(key, value).then(function () { return value; });
            log("Cached value");
        }
        catch (error) {
            (0, log_1.traceJSON)(value, "Failed to set \"".concat(key, "\" in cache to"), log);
            throw new Error("Failed to set \"".concat(key, "\" in cache to value: ").concat(value));
        }
        return [2 /*return*/];
    });
}); };
//# sourceMappingURL=cache.js.map