import { GatsbyCache } from 'gatsby';
import { ComposeInputTypeDefinition, ObjectTypeComposerFieldConfigAsObjectDefinition } from 'graphql-compose';
import { IImgixURLBuilder } from '../../common/imgix-js-core-wrapper';
import { ImgixSourceDataResolver } from '../../common/utils';
import { IImgixParams } from '../../publicTypes';
import { ImgixFixedArgsResolved } from './privateTypes';
export declare const DEFAULT_FIXED_WIDTH = 8192;
interface CreateImgixFixedFieldConfigArgs<TSource> {
    imgixClient: IImgixURLBuilder;
    resolveUrl: ImgixSourceDataResolver<TSource, string>;
    resolveWidth?: ImgixSourceDataResolver<TSource, number | undefined>;
    resolveHeight?: ImgixSourceDataResolver<TSource, number | undefined>;
    cache: GatsbyCache;
    defaultParams?: Partial<IImgixParams>;
    type: string;
    paramsInputType: ComposeInputTypeDefinition;
}
/**
 * Create the GraphQL field config for the "fixed" field that will exist on the
 * imgixImage type
 * @param param0
 * @param param0.imgixClient The imgix client to use to build the URL
 * @param param0.resolveUrl The function to resolve the URL from the source data
 * @param param0.resolveWidth A function should should resolve the width from the source data. If not provided, the imgix api will be used to find the image width
 * @param param0.resolveHeight A function should should resolve the height from the source data. If not provided, the imgix api will be used to find the image height
 * @param param0.cache Gatsby cache
 * @param param0.defaultParams The default params to use when building the fixed image URL
 * @param param0.type The GraphQL type to use for the fixed field
 * @param param0.paramsInputType The GraphQL type to use for the params input
 * @returns A GraphQL field config for a "fixed" size image
 */
export declare const createImgixFixedFieldConfig: <TSource, TContext>({ imgixClient, resolveUrl, resolveWidth, resolveHeight, cache, defaultParams, type, paramsInputType, }: CreateImgixFixedFieldConfigArgs<TSource>) => ObjectTypeComposerFieldConfigAsObjectDefinition<TSource, TContext, ImgixFixedArgsResolved>;
export declare const createImgixFixedSchemaFieldConfig: <TSource, TContext>(params: Omit<CreateImgixFixedFieldConfigArgs<unknown>, "imgixClient" | "resolveUrl"> & {
    imgixClientOptions?: import("../../common/imgix-js-core-wrapper").CreateImgixClientParams | undefined;
    resolveUrl?: ((source: TSource) => string | null | undefined) | undefined;
}) => ObjectTypeComposerFieldConfigAsObjectDefinition<TSource, TContext, any>;
export {};
//# sourceMappingURL=createImgixFixedFieldConfig.d.ts.map