"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createImgixFluidSchemaFieldConfig = exports.createImgixFluidFieldConfig = void 0;
var createExternalHelper_1 = require("../../common/createExternalHelper");
var graphqlTypes_1 = require("./graphqlTypes");
var objectBuilders_1 = require("./objectBuilders");
var resolveDimensions_1 = require("./resolveDimensions");
var DEFAULT_FLUID_MAX_WIDTH = 8192;
/**
 * Create the GraphQL field config for the "fluid" field that will exist on the
 * imgixImage type
 * @param param0
 * @param param0.imgixClient The imgix client to use to build the URL
 * @param param0.resolveUrl The function to resolve the URL from the source data
 * @param param0.resolveWidth A function should should resolve the width from the source data. If not provided, the imgix api will be used to find the image width
 * @param param0.resolveHeight A function should should resolve the height from the source data. If not provided, the imgix api will be used to find the image height
 * @param param0.cache Gatsby cache
 * @param param0.defaultParams The default params to use when building the fixed image URL
 * @param param0.type The GraphQL type to use for the fluid field
 * @param param0.paramsInputType The GraphQL type to use for the params input
 * @returns A GraphQL field config for a "fluid" size image
 */
var createImgixFluidFieldConfig = function (_a) {
    var imgixClient = _a.imgixClient, resolveUrl = _a.resolveUrl, _b = _a.resolveWidth, resolveWidth = _b === void 0 ? function () { return undefined; } : _b, _c = _a.resolveHeight, resolveHeight = _c === void 0 ? function () { return undefined; } : _c, cache = _a.cache, defaultParams = _a.defaultParams, type = _a.type, paramsInputType = _a.paramsInputType;
    return ({
        type: type,
        description: "Should be used to generate fluid-width images (i.e. images that change when the size of the browser changes). Returns data compatible with gatsby-image. Instead of accessing this data directly, the GatsbySourceImgixFluid fragment should be used. See the project's README for more information.",
        args: {
            imgixParams: {
                type: paramsInputType,
                description: "The imgix parameters (transformations) to apply to the image. The full set of imgix params can be explored here: https://docs.imgix.com/apis/url",
                defaultValue: {},
            },
            maxWidth: {
                type: 'Int',
                description: "The maximum px width of the *image* to be *requested*. This does NOT affect the width of the image displayed. The width of the image displayed can be controlled by adding a sizes parameter to the GatsbyImage component. For more information, see this project's readme.",
                defaultValue: DEFAULT_FLUID_MAX_WIDTH,
            },
            maxHeight: {
                description: "The maximum px height of the *image* to be *requested*. This does NOT affect the height of the image displayed.",
                type: 'Int',
            },
            srcSetBreakpoints: {
                type: '[Int]',
                description: "A custom set of widths (in px) to use for the srcset widths. This feature is not recommended as the default widths are optimized for imgix's caching infrastructure.",
            },
            placeholderImgixParams: {
                type: paramsInputType,
                description: "Any imgix parameters to use only for the blur-up/placeholder image. The full set of imgix params can be explored here: https://docs.imgix.com/apis/url",
                defaultValue: {},
            },
        },
        resolve: function (rootValue, args) { return __awaiter(void 0, void 0, void 0, function () {
            var modifiedArgs, url, manualWidth, manualHeight, _a, width, height;
            return __generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        modifiedArgs = __assign(__assign({}, args), { imgixParams: (0, graphqlTypes_1.unTransformParams)(args.imgixParams) });
                        return [4 /*yield*/, resolveUrl(rootValue)];
                    case 1:
                        url = _b.sent();
                        if (!url) {
                            return [2 /*return*/, undefined];
                        }
                        return [4 /*yield*/, resolveWidth(rootValue)];
                    case 2:
                        manualWidth = _b.sent();
                        return [4 /*yield*/, resolveHeight(rootValue)];
                    case 3:
                        manualHeight = _b.sent();
                        return [4 /*yield*/, (0, resolveDimensions_1.resolveDimensions)({
                                url: url,
                                manualWidth: manualWidth,
                                manualHeight: manualHeight,
                                cache: cache,
                                client: imgixClient,
                            })];
                    case 4:
                        _a = _b.sent(), width = _a.width, height = _a.height;
                        return [2 /*return*/, (0, objectBuilders_1.buildFluidObject)({
                                client: imgixClient,
                                args: modifiedArgs,
                                sourceHeight: height,
                                sourceWidth: width,
                                url: url,
                                defaultParams: defaultParams,
                                defaultPlaceholderParams: {}, // TODO: implement
                            })];
                }
            });
        }); },
    });
};
exports.createImgixFluidFieldConfig = createImgixFluidFieldConfig;
exports.createImgixFluidSchemaFieldConfig = (0, createExternalHelper_1.createExternalHelper)(exports.createImgixFluidFieldConfig);
//# sourceMappingURL=createImgixFluidFieldConfig.js.map