import { GatsbyCache } from 'gatsby';
import { ComposeInputTypeDefinition, ObjectTypeComposerFieldConfigAsObjectDefinition } from 'graphql-compose';
import { TypeAsString } from 'graphql-compose/lib/TypeMapper';
import { IImgixURLBuilder } from '../../common/imgix-js-core-wrapper';
import { ImgixSourceDataResolver } from '../../common/utils';
import { IImgixParams } from '../../publicTypes';
import { IImgixGatsbyImageDataArgsResolved } from './privateTypes';
/**
 * Create the GraphQL field config for the gatsbyImage field that will exist on
 * the imgixImage type
 * @param param0
 * @param param0.cache Gatsby cache
 * @param param0.imgixClient The imgix client to use to build the URL
 * @param param0.resolveUrl The function to resolve the URL from the source data
 * @param param0.defaultParams The default params to use when building the fixed image URL
 * @param param0.paramsInputType The GraphQL type to use for the params input
 * @param param0.placeholderEnumType The GraphQL type to use for the placeholder enum
 * @param param0.resolveWidth A function should should resolve the width from the source data. If not provided, the imgix api will be used to find the image width
 * @param param0.resolveHeight A function should should resolve the height from the source data. If not provided, the imgix api will be used to find the image height
 * @returns A GraphQL field config for a "gatsbyImage" field
 */
export declare const createImgixGatsbyImageFieldConfig: <TSource, TContext = {}>({ cache, imgixClient, resolveUrl, defaultParams, paramsInputType, placeholderEnumType, resolveWidth, resolveHeight, }: {
    imgixClient: IImgixURLBuilder;
    resolveUrl: ImgixSourceDataResolver<TSource, string>;
    resolveWidth?: ImgixSourceDataResolver<TSource, number | undefined> | undefined;
    resolveHeight?: ImgixSourceDataResolver<TSource, number | undefined> | undefined;
    cache: GatsbyCache;
    defaultParams?: Partial<Partial<Record<"auto" | "fill" | "blendalign" | "ba" | "blend" | "blendalpha" | "balph" | "blendcolor" | "blend-clr" | "blendclr" | "faces" | "blendcrop" | "bc" | "crop" | "blendfit" | "bf" | "blendh" | "bh" | "hue" | "blendmode" | "bm" | "blendpad" | "bp" | "blendsize" | "bs" | "blendw" | "bw" | "blendx" | "bx" | "blendy" | "by" | "b" | "border" | "width" | "dpr" | "palette" | "mask" | "duotone" | "fillcolor" | "blur" | "fit" | "f" | "h" | "transparency" | "height" | "invert" | "inv" | "ma" | "markalign" | "mark" | "markalpha" | "malph" | "mb" | "markbase" | "mf" | "markfit" | "markw" | "markh" | "mh" | "mp" | "markpad" | "ms" | "markscale" | "mtile" | "marktile" | "mw" | "mx" | "markx" | "my" | "marky" | "m" | "maskbg" | "max-height" | "max-width" | "min-height" | "min-width" | "monochrome" | "mono" | "or" | "annotation" | "trim" | "trimcolor" | "trimmd" | "trimpad" | "trimsd" | "trimtol" | "txtalign" | "ta" | "txt" | "txtclip" | "tcl" | "txtcolor" | "txt-clr" | "txtclr" | "tc" | "txtfit" | "tf" | "txtfont" | "txtlead" | "txtlig" | "txtlinecolor" | "txt-line-clr" | "txtlineclr" | "txtline" | "tl" | "txtpad" | "tp" | "txtshad" | "tsh" | "tsz" | "txtsize" | "txttrack" | "tt" | "txtwidth" | "t" | "usm" | "blend-align" | "blend-alpha" | "blend-color" | "blend-crop" | "blend-fit" | "blend-h" | "blend-mode" | "blend-pad" | "blend-size" | "blend-w" | "blend-x" | "blend-y" | "fill-color" | "mark-align" | "mark-alpha" | "mark-base" | "mark-fit" | "mark-h" | "mark-pad" | "mark-scale" | "mark-tile" | "mark-w" | "mark-x" | "mark-y" | "mask-bg" | "max-h" | "max-w" | "min-h" | "min-w" | "orient" | "pdf-annotation" | "trim-color" | "trim-md" | "trim-pad" | "trim-sd" | "trim-tol" | "txt-align" | "txt-clip" | "txt-color" | "txt-fit" | "txt-font" | "txt-lead" | "txt-lig" | "txt-line-color" | "txt-line" | "txt-pad" | "txt-shad" | "txt-size" | "txt-track" | "txt-width" | "w" | "ar" | "bg" | "border-bottom" | "border-left" | "border-radius-inner" | "border-radius" | "border-right" | "border-top" | "bri" | "ch" | "chromasub" | "colorquant" | "colors" | "con" | "corner-radius" | "cs" | "dl" | "dpi" | "duotone-alpha" | "exp" | "expires" | "faceindex" | "facepad" | "flip" | "fm" | "fp-debug" | "fp-x" | "fp-y" | "fp-z" | "gam" | "grid-colors" | "grid-size" | "high" | "htn" | "iptc" | "lossless" | "mark-rot" | "nr" | "nrs" | "pad-bottom" | "pad-left" | "pad-right" | "pad-top" | "pad" | "page" | "prefix" | "px" | "q" | "rect" | "rot" | "sat" | "sepia" | "shad" | "sharp" | "usmrad" | "vib", string | number | boolean | string[] | number[] | boolean[] | null | undefined>>> | undefined;
    paramsInputType: ComposeInputTypeDefinition;
    placeholderEnumType: TypeAsString;
}) => ObjectTypeComposerFieldConfigAsObjectDefinition<TSource, TContext, IImgixGatsbyImageDataArgsResolved>;
export declare const createImgixGatsbyImageSchemaFieldConfig: <TSource, TContext>(params: Omit<{
    imgixClient: IImgixURLBuilder;
    resolveUrl: ImgixSourceDataResolver<unknown, string>;
    resolveWidth?: ImgixSourceDataResolver<unknown, number | undefined> | undefined;
    resolveHeight?: ImgixSourceDataResolver<unknown, number | undefined> | undefined;
    cache: GatsbyCache;
    defaultParams?: Partial<Partial<Record<"auto" | "fill" | "blendalign" | "ba" | "blend" | "blendalpha" | "balph" | "blendcolor" | "blend-clr" | "blendclr" | "faces" | "blendcrop" | "bc" | "crop" | "blendfit" | "bf" | "blendh" | "bh" | "hue" | "blendmode" | "bm" | "blendpad" | "bp" | "blendsize" | "bs" | "blendw" | "bw" | "blendx" | "bx" | "blendy" | "by" | "b" | "border" | "width" | "dpr" | "palette" | "mask" | "duotone" | "fillcolor" | "blur" | "fit" | "f" | "h" | "transparency" | "height" | "invert" | "inv" | "ma" | "markalign" | "mark" | "markalpha" | "malph" | "mb" | "markbase" | "mf" | "markfit" | "markw" | "markh" | "mh" | "mp" | "markpad" | "ms" | "markscale" | "mtile" | "marktile" | "mw" | "mx" | "markx" | "my" | "marky" | "m" | "maskbg" | "max-height" | "max-width" | "min-height" | "min-width" | "monochrome" | "mono" | "or" | "annotation" | "trim" | "trimcolor" | "trimmd" | "trimpad" | "trimsd" | "trimtol" | "txtalign" | "ta" | "txt" | "txtclip" | "tcl" | "txtcolor" | "txt-clr" | "txtclr" | "tc" | "txtfit" | "tf" | "txtfont" | "txtlead" | "txtlig" | "txtlinecolor" | "txt-line-clr" | "txtlineclr" | "txtline" | "tl" | "txtpad" | "tp" | "txtshad" | "tsh" | "tsz" | "txtsize" | "txttrack" | "tt" | "txtwidth" | "t" | "usm" | "blend-align" | "blend-alpha" | "blend-color" | "blend-crop" | "blend-fit" | "blend-h" | "blend-mode" | "blend-pad" | "blend-size" | "blend-w" | "blend-x" | "blend-y" | "fill-color" | "mark-align" | "mark-alpha" | "mark-base" | "mark-fit" | "mark-h" | "mark-pad" | "mark-scale" | "mark-tile" | "mark-w" | "mark-x" | "mark-y" | "mask-bg" | "max-h" | "max-w" | "min-h" | "min-w" | "orient" | "pdf-annotation" | "trim-color" | "trim-md" | "trim-pad" | "trim-sd" | "trim-tol" | "txt-align" | "txt-clip" | "txt-color" | "txt-fit" | "txt-font" | "txt-lead" | "txt-lig" | "txt-line-color" | "txt-line" | "txt-pad" | "txt-shad" | "txt-size" | "txt-track" | "txt-width" | "w" | "ar" | "bg" | "border-bottom" | "border-left" | "border-radius-inner" | "border-radius" | "border-right" | "border-top" | "bri" | "ch" | "chromasub" | "colorquant" | "colors" | "con" | "corner-radius" | "cs" | "dl" | "dpi" | "duotone-alpha" | "exp" | "expires" | "faceindex" | "facepad" | "flip" | "fm" | "fp-debug" | "fp-x" | "fp-y" | "fp-z" | "gam" | "grid-colors" | "grid-size" | "high" | "htn" | "iptc" | "lossless" | "mark-rot" | "nr" | "nrs" | "pad-bottom" | "pad-left" | "pad-right" | "pad-top" | "pad" | "page" | "prefix" | "px" | "q" | "rect" | "rot" | "sat" | "sepia" | "shad" | "sharp" | "usmrad" | "vib", string | number | boolean | string[] | number[] | boolean[] | null | undefined>>> | undefined;
    paramsInputType: ComposeInputTypeDefinition;
    placeholderEnumType: TypeAsString;
}, "imgixClient" | "resolveUrl"> & {
    imgixClientOptions?: import("../../common/imgix-js-core-wrapper").CreateImgixClientParams | undefined;
    resolveUrl?: ((source: TSource) => string | null | undefined) | undefined;
}) => ObjectTypeComposerFieldConfigAsObjectDefinition<TSource, TContext, any>;
//# sourceMappingURL=createImgixGatsbyImageDataFieldConfig.d.ts.map