"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pluginOptionsSchema = void 0;
var parameters_json_1 = __importDefault(require("imgix-url-params/dist/parameters.json"));
var ramda_1 = require("ramda");
/**
 * Run during the bootstrap phase. Plugins can use this to define a schema for
 * their options using Joi to validate the options users pass to the plugin.
 *
 * @see https://www.gatsbyjs.com/docs/reference/config-files/gatsby-node/#pluginOptionsSchema
 */
var pluginOptionsSchema = function (args) {
    var Joi = args.Joi;
    var ImgixSourceTypeJOI = Joi.string().valid('s3', 'gcs', 'azure', 'webFolder', 'webProxy');
    var ImgixParamValueJOI = Joi.alternatives()
        .try(Joi.string(), Joi.number(), Joi.boolean(), Joi.array().items(Joi.string()), Joi.array().items(Joi.number()), Joi.array().items(Joi.boolean()))
        .optional()
        .allow(null);
    var mapToImgixParamJOIValue = function (obj) {
        return (0, ramda_1.mapObjIndexed)(function () { return ImgixParamValueJOI; }, obj);
    };
    var ImgixParamsJOI = Joi.object().keys(__assign(__assign({}, mapToImgixParamJOIValue(parameters_json_1.default.aliases)), mapToImgixParamJOIValue(parameters_json_1.default.parameters)));
    var ImgixGatsbyFieldsJOI = Joi.array().items(Joi.object()
        .keys({
        nodeType: Joi.string()
            .required()
            .description('The GraphQL node type to modify.'),
        fieldName: Joi.string()
            .required()
            .description('The name for the imgix field that will be added to the corresponding node type'),
        URLPrefix: Joi.string()
            .optional()
            .description('The prefix to add to the image URL resolved from the node data'),
        rawURLKeys: Joi.array()
            .items(Joi.string())
            .description('Where to get the image URL from the node data'),
        rawURLKey: Joi.string().description('The path to get the image URL from the node data'),
    })
        .xor('rawURLKeys', 'rawURLKey'));
    var schema = Joi.object().keys({
        domain: Joi.string()
            .required()
            .description("This is the domain of your imgix source, which can be created at https://dashboard.imgix.com/. The source specified must be a 'Web Proxy' source type."),
        secureURLToken: Joi.string()
            .optional()
            .description("This is the source's secure token. Can be found under the 'Security' heading in your source's configuration page, and revealed by tapping 'Show Token'."),
        defaultImgixParams: ImgixParamsJOI.optional().description('These are the default imgix parameters to apply to every image.'),
        disableIxlibParam: Joi.boolean()
            .optional()
            .description('Set to `true` to remove the `ixlib` param from every request.'),
        sourceType: ImgixSourceTypeJOI.optional().description('This should specify the type of imgix source that is used for this plugin'),
        fields: ImgixGatsbyFieldsJOI.optional().description('If set, the plugin will transform these node types to add imgixImage fields to the corresponding types.'),
        // This seems to be added by Gatsby automatically, although it has no
        // relevance to our plugin. We have to include this otherwise validation
        // fails
        plugins: Joi.any(),
    });
    return schema;
};
exports.pluginOptionsSchema = pluginOptionsSchema;
//# sourceMappingURL=pluginOptionsSchema.js.map