import { GatsbyCache } from 'gatsby';
import { EnumTypeComposerAsObjectDefinition, InputTypeComposerAsObjectDefinition, ObjectTypeComposerAsObjectDefinition, ObjectTypeComposerFieldConfigAsObjectDefinition } from 'graphql-compose';
import { IImgixURLBuilder } from '../../common/imgix-js-core-wrapper';
import { ImgixSourceDataResolver } from '../../common/utils';
import { IImgixParams } from '../../publicTypes';
/**
 * This function can be used to return a set of graphql-compose types that should be passed to schema.createObjectType
 */
export declare const buildImgixGatsbyTypes: <TSource>({ allowlistFields, imgixClient, resolveUrl, resolveWidth, resolveHeight, defaultParams, cache, namespace, }: {
    allowlistFields?: ("url" | "fixed" | "fluid" | "gatsbyImageData")[] | undefined;
    namespace?: string | undefined;
    imgixClient: IImgixURLBuilder;
    resolveUrl: ImgixSourceDataResolver<TSource, string>;
    resolveHeight?: ImgixSourceDataResolver<TSource, number | undefined> | undefined;
    resolveWidth?: ImgixSourceDataResolver<TSource, number | undefined> | undefined;
    defaultParams?: Partial<Record<"auto" | "fill" | "blendalign" | "ba" | "blend" | "blendalpha" | "balph" | "blendcolor" | "blend-clr" | "blendclr" | "faces" | "blendcrop" | "bc" | "crop" | "blendfit" | "bf" | "blendh" | "bh" | "hue" | "blendmode" | "bm" | "blendpad" | "bp" | "blendsize" | "bs" | "blendw" | "bw" | "blendx" | "bx" | "blendy" | "by" | "b" | "border" | "width" | "dpr" | "palette" | "mask" | "duotone" | "fillcolor" | "blur" | "fit" | "f" | "h" | "transparency" | "height" | "invert" | "inv" | "ma" | "markalign" | "mark" | "markalpha" | "malph" | "mb" | "markbase" | "mf" | "markfit" | "markw" | "markh" | "mh" | "mp" | "markpad" | "ms" | "markscale" | "mtile" | "marktile" | "mw" | "mx" | "markx" | "my" | "marky" | "m" | "maskbg" | "max-height" | "max-width" | "min-height" | "min-width" | "monochrome" | "mono" | "or" | "annotation" | "trim" | "trimcolor" | "trimmd" | "trimpad" | "trimsd" | "trimtol" | "txtalign" | "ta" | "txt" | "txtclip" | "tcl" | "txtcolor" | "txt-clr" | "txtclr" | "tc" | "txtfit" | "tf" | "txtfont" | "txtlead" | "txtlig" | "txtlinecolor" | "txt-line-clr" | "txtlineclr" | "txtline" | "tl" | "txtpad" | "tp" | "txtshad" | "tsh" | "tsz" | "txtsize" | "txttrack" | "tt" | "txtwidth" | "t" | "usm" | "blend-align" | "blend-alpha" | "blend-color" | "blend-crop" | "blend-fit" | "blend-h" | "blend-mode" | "blend-pad" | "blend-size" | "blend-w" | "blend-x" | "blend-y" | "fill-color" | "mark-align" | "mark-alpha" | "mark-base" | "mark-fit" | "mark-h" | "mark-pad" | "mark-scale" | "mark-tile" | "mark-w" | "mark-x" | "mark-y" | "mask-bg" | "max-h" | "max-w" | "min-h" | "min-w" | "orient" | "pdf-annotation" | "trim-color" | "trim-md" | "trim-pad" | "trim-sd" | "trim-tol" | "txt-align" | "txt-clip" | "txt-color" | "txt-fit" | "txt-font" | "txt-lead" | "txt-lig" | "txt-line-color" | "txt-line" | "txt-pad" | "txt-shad" | "txt-size" | "txt-track" | "txt-width" | "w" | "ar" | "bg" | "border-bottom" | "border-left" | "border-radius-inner" | "border-radius" | "border-right" | "border-top" | "bri" | "ch" | "chromasub" | "colorquant" | "colors" | "con" | "corner-radius" | "cs" | "dl" | "dpi" | "duotone-alpha" | "exp" | "expires" | "faceindex" | "facepad" | "flip" | "fm" | "fp-debug" | "fp-x" | "fp-y" | "fp-z" | "gam" | "grid-colors" | "grid-size" | "high" | "htn" | "iptc" | "lossless" | "mark-rot" | "nr" | "nrs" | "pad-bottom" | "pad-left" | "pad-right" | "pad-top" | "pad" | "page" | "prefix" | "px" | "q" | "rect" | "rot" | "sat" | "sepia" | "shad" | "sharp" | "usmrad" | "vib", string | number | boolean | string[] | number[] | boolean[] | null | undefined>> | undefined;
    cache: GatsbyCache;
}) => {
    types: ObjectTypeComposerAsObjectDefinition<any, unknown>[];
    fields: Record<"url" | "fixed" | "fluid" | "gatsbyImageData", ObjectTypeComposerFieldConfigAsObjectDefinition<any, any, any>>;
    inputTypes: InputTypeComposerAsObjectDefinition[];
    enumTypes: EnumTypeComposerAsObjectDefinition[];
};
//# sourceMappingURL=typeBuilder.d.ts.map